@@ -7,24 +7,19 @@ mod page_stream;
 #[cfg(feature = "stream")]
 mod stream;
 
-pub use streaming_iterator;
-pub use streaming_iterator::StreamingIterator;
-
-pub use compression::{decompress, Decompressor};
-
-pub use metadata::read_metadata;
-#[cfg(feature = "stream")]
-pub use stream::read_metadata as read_metadata_async;
-
 use std::io::{Read, Seek, SeekFrom};
 use std::sync::Arc;
 
-use crate::metadata::{ColumnChunkMetaData, RowGroupMetaData};
-use crate::{error::Result, metadata::FileMetaData};
-
+pub use compression::{decompress, BasicDecompressor, Decompressor};
+pub use metadata::read_metadata;
 pub use page_iterator::{PageFilter, PageIterator};
 #[cfg(feature = "stream")]
 pub use page_stream::get_page_stream;
+#[cfg(feature = "stream")]
+pub use stream::read_metadata as read_metadata_async;
+
+use crate::metadata::{ColumnChunkMetaData, RowGroupMetaData};
+use crate::{error::Result, metadata::FileMetaData};
 
 /// Filters row group metadata to only those row groups,
 /// for which the predicate function returns true
@@ -67,6 +62,8 @@ pub fn get_page_iterator<'a, RR: Read + Seek>(
 mod tests {
     use std::fs::File;
 
+    use crate::FallibleStreamingIterator;
+
     use super::*;
 
     use crate::tests::get_path;
@@ -93,7 +90,7 @@ mod tests {
     #[test]
     fn reuse_buffer() -> Result<()> {
         let mut testdata = get_path();
-        testdata.push("alltypes_plain.parquet");
+        testdata.push("alltypes_plain.snappy.parquet");
         let mut file = File::open(testdata).unwrap();
 
         let metadata = read_metadata(&mut file)?;
@@ -102,13 +99,17 @@ mod tests {
         let column = 0;
         let column_metadata = metadata.row_groups[row_group].column(column);
         let buffer = vec![0];
-        let mut iterator = get_page_iterator(column_metadata, &mut file, None, buffer)?;
+        let iterator = get_page_iterator(column_metadata, &mut file, None, buffer)?;
 
-        let page = iterator.next().unwrap().unwrap();
-        iterator.reuse_buffer(page.buffer);
+        let buffer = vec![];
+        let mut iterator = Decompressor::new(iterator, buffer);
 
-        assert!(iterator.next().is_none());
-        assert!(!iterator.buffer.is_empty());
+        let _ = iterator.next()?.unwrap();
+
+        assert!(iterator.next()?.is_none());
+        let (a, b) = iterator.into_buffers();
+        assert_eq!(a.len(), 11); // note: compressed is higher in this example.
+        assert_eq!(b.len(), 9);
 
         Ok(())
     }
@@ -130,9 +131,9 @@ mod tests {
         let buffer = vec![];
         let mut iterator = Decompressor::new(iterator, buffer);
 
-        iterator.next().unwrap().as_ref().unwrap();
+        iterator.next()?.unwrap();
 
-        assert!(iterator.next().is_none());
+        assert!(iterator.next()?.is_none());
         let (a, b) = iterator.into_buffers();
 
         assert_eq!(a.len(), 11);
